"""Free Games

"""

from .utils import floor, line, path, square, vector

__title__ = 'freegames'
__version__ = '2.0.1'
__build__ = 0x020001
__author__ = 'Grant Jenks'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2017 Grant Jenks'
